# use-proper-hosting
No more support server flooding with questions about unsupported hosting.  
If you want to block other hosting platform, feel free to contribute.

## Installation
```
pip install -U use-proper-hosting
```

## Example

```py
from use_proper_hosting import detect_repl

detect_repl()
```
![](https://github.com/playground1104/use-proper-hosting/blob/master/.github/example.png?raw=true)
